==> flutter_xmp-0.0.1.tar.gz: android/src/main/java/br/com/queizysartori/flutterxmp/flutter_xmp/FlutterXmpPlugin.java <==
package br.com.queizysartori.flutterxmp.flutter_xmp;

import android.content.Context;

import androidx.annotation.NonNull;

import java.util.Map;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/** FlutterXmpPlugin */
public class FlutterXmpPlugin implements FlutterPlugin, MethodCallHandler {
  private MethodChannel channel;

  private Context mContext;

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    mContext = flutterPluginBinding.getApplicationContext();
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "flutter_xmp");
    channel.setMethodCallHandler(this);
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull final Result result) {
    if (call.method.equals("extractXmpFromRemote")) {
      RemoteImageXmpFetcher.fetch(
              call.<String>argument("url"),
              mContext,
              new MetadataCallbackImp() {
                @Override
                public void onSuccess(Map<String, String> metadata) {
                  result.success(metadata);
                }
              }
      );
    } else {
      result.notImplemented();
    }
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }
}

==> flutter_xmp-1.0.1.tar.gz: android/src/main/java/br/com/queizysartori/flutterxmp/flutter_xmp/FlutterXmpPlugin.java <==
package br.com.queizysartori.flutterxmp.flutter_xmp;

import android.content.Context;

import androidx.annotation.NonNull;

import java.util.Map;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/** FlutterXmpPlugin */
public class FlutterXmpPlugin implements FlutterPlugin, MethodCallHandler {
  private MethodChannel channel;
  private Context mContext;

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    mContext = flutterPluginBinding.getApplicationContext();
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "flutter_xmp");
    channel.setMethodCallHandler(this);
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull final Result result) {
    if (call.method.equals("extractXmpFromRemote")) {
      RemoteImageXmpFetcher.fetch(
        call.<String>argument("url"),
        mContext,
        new MetadataCallbackImp() {
          @Override
          public void onSuccess(XmpResult xmpResult) {
            result.success(xmpResult.toMap());
          }
        }
      );
    } else {
      result.notImplemented();
    }
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }
}
